@@ -1,4 +1,4 @@
-# Copyright 2011-2021 Louis Paternault
+# Copyright 2011-2022 Louis Paternault
 #
 # This file is part of pdfimpose.
 #
@@ -20,23 +20,19 @@
 import logging
 import sys
 
+from ... import UserError
+from .. import ArgumentParser
 from . import __doc__ as DESCRIPTION
 from . import impose
-from .. import common as schema
-from ... import UserError
 
 
 def main(argv=None):
     """Main function"""
 
-    parser = schema.ArgumentParser(
+    parser = ArgumentParser(
         subcommand="onepagezine",
         options=["omargin", "mark", "last", "bind"],
         description=DESCRIPTION,
-        epilog=(
-            "This command only perform imposition of the front of your fanzine. "
-            "It is your job to print the poster on the back."
-        ),
     )
 
     try:
